Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(365)

Unified Diff: ui/aura/mus/window_port_mus.h

Issue 2456843004: Wires up transient windows for aura-mus (Closed)
Patch Set: Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/aura/mus/window_port_mus.h
diff --git a/ui/aura/mus/window_port_mus.h b/ui/aura/mus/window_port_mus.h
index d591a368174c7669fe94ba3dd7923877f217b970..c94b0a8df558c26c09db05e13d86c6bf02c02f4d 100644
--- a/ui/aura/mus/window_port_mus.h
+++ b/ui/aura/mus/window_port_mus.h
@@ -93,16 +93,18 @@ class AURA_EXPORT WindowPortMus : public WindowPort, public WindowMus {
// window_tree_client_->OnFooChanged(this, ...);
enum ServerChangeType {
ADD,
+ ADD_TRANSIENT,
BOUNDS,
PROPERTY,
REMOVE,
+ REMOVE_TRANSIENT,
REORDER,
VISIBLE,
};
// Contains data needed to identify a change from the server.
struct ServerChangeData {
// Applies to ADD, REMOVE and REORDER.
Id child_id;
// Applies to BOUNDS.
gfx::Rect bounds;
@@ -177,6 +179,10 @@ class AURA_EXPORT WindowPortMus : public WindowPort, public WindowMus {
const std::vector<uint8_t>* property_data) override;
void SetSurfaceIdFromServer(
std::unique_ptr<SurfaceInfo> surface_info) override;
+ void AddTransientChildFromServer(WindowMus* child) override;
+ void RemoveTransientChildFromServer(WindowMus* child) override;
+ ChangeSource OnTransientChildAdded(WindowMus* child) override;
+ ChangeSource OnTransientChildRemoved(WindowMus* child) override;
std::unique_ptr<WindowMusChangeData> PrepareForServerBoundsChange(
const gfx::Rect& bounds) override;
std::unique_ptr<WindowMusChangeData> PrepareForServerVisibilityChange(
@@ -93,16 +93,18 @@ class AURA_EXPORT WindowPortMus : public WindowPort, public WindowMus {
// Contains data needed to identify a change from the server.
struct ServerChangeData {
- // Applies to ADD, REMOVE and REORDER.
+ // Applies to ADD, ADD_TRANSIENT, REMOVE and REORDER.
Id child_id;
// Applies to BOUNDS.

Powered by Google App Engine
This is Rietveld 408576698